use strict;
use warnings;
use Data::Dumper; $Data::Dumper::Indent = 1;
use Test::More 'no_plan';

use Atompub::Client;
use FindBin;
use HTTP::Status;
use XML::Atom::Entry;

#system "sqlite3 $FindBin::Bin/../test.db < $FindBin::Bin/../init.sql" || die;

ok my $client = Atompub::Client->new;

ok my $service = $client->getService('http://localhost:3000/service');

# サービス文書のカスタマイズ のテスト

my($entry_collection, $media_collection)
    = map { $_->href } $service->workspace->collections;

is $entry_collection, 'http://localhost:3000/entrycollection';

# 認証 のテスト

my $entry = XML::Atom::Entry->new;
   $entry->title('Entry 1');
   $entry->content('This is the 1st entry');

ok ! $client->createEntry($entry_collection, $entry, 'Entry 1');
is $client->res->code, RC_UNAUTHORIZED;

$client->username('guest');
$client->password('abc');

ok my $uri = $client->createEntry($entry_collection, $entry, 'Entry 1');
is $uri, "$entry_collection/entry_1.atom";

# メンバリソースの URI の指定 のテスト

for my $i (2..11) {
    ok $uri = $client->createEntry($entry_collection, $entry, 'Entry 1');
    like $uri, qr{$entry_collection/entry_1-\d+.atom};
}

# キャッシュ・バージョンチェック のテスト

ok $entry = $client->getEntry($uri);
is $client->res->code, RC_NOT_MODIFIED;

# フィードのページング のテスト

my $feed = $client->getFeed($entry_collection);
is   $feed->first_link, $entry_collection;
ok ! $feed->previous_link;
is   $feed->next_link, "$entry_collection?page=2";
is   $feed->entries, 10;

$feed = $client->getFeed("$entry_collection?page=2");
is   $feed->first_link, $entry_collection;
is   $feed->previous_link, "$entry_collection?page=1";
ok ! $feed->next_link;
is   $feed->entries, 1;

# エラー処理 のテスト

ok ! $client->getEntry("$entry_collection/no_such_entry");
is $client->res->code, RC_NOT_FOUND;
is(XML::Atom::Entry->new(\$client->res->content)->title, RC_NOT_FOUND.' Entry does not exist');

